#!/bin/bash

# USB Malware Detection Script Version 2.1
# Written by Jason Lai
# Code elements adapted from Wen Jie Zhou, Yilok Wong, and Chuck Sakoda
# Front-end adapted from Luke Ackerman
# Adapted for use on general Linux systems at LEPP by Devin Bougie

srcdir=`dirname $0`
outdir="/tmp/$USER"
mediadir="/media"

#create the outdir if doesn't already exist
[ ! -d $outdir ] && mkdir $outdir

#remove results.txt created from the last test
[ -f $outdir/results.txt ] && rm $outdir/results.txt

clear

#check for presence of mounted USB drive
if [ ! -d $mediadir/* ];
then #no device is attached
	printf "No device could be detected to scan.  Please wait a few seconds and try again." >> $outdir/results.txt
	firefox $srcdir/missing.html
	exit -1
fi

#Remount the USB drive with the sync command to prevent data loss caused by removing device before unmounting
#mount -o remount,sync $mediadir/*

#check for autorun.inf~ backup file and remove it because it can interfere with search
cd $mediadir/
AUTORUNBACKUP=$(ls -al -R | grep -ic "autorun.inf~")
if [ $AUTORUNBACKUP -ne 0 ];
then #autorun.inf~ exists 
	rm $mediadir/*/autorun.inf~
fi

#check for autorun.inf
AUTORUN=$(ls -al -R | grep -ic "autorun.inf")
if [ $AUTORUN -ne 0 ];
then #autorun.inf exists 		
	printf "There exists an 'autorun.inf' file on the media\n" >> $outdir/results.txt
	cat $mediadir/*/autorun.inf >> $outdir/autorun.txt #copy autorun.inf into autorun.txt text file on desktop for easy searching
	
	#check for LaunchU3 in autorun file
	GOODLAUNCHONAR=$(grep -ic "U3" $outdir/autorun.txt)	
	if [ $GOODLAUNCHONAR -eq 0 ];
	then #Autorun exists, No U3 exists in the autorun file
		printf "There is no mention of 'U3' in the autorun.inf file\n" >> $outdir/results.txt
		
		#check for sketchy executables referenced in autorun	
		EXEINAR=$(grep -ic ".exe" $outdir/autorun.txt)
		if [ $EXEINAR -ne 0 ];
		then #Autorun exists, no U3 in autorun, suspicious exe in autorun
			printf "There are suspicious executable files referenced in autorun.inf\n" >> $outdir/results.txt
			rm $outdir/autorun.txt
			
			#Test for bad stuff on media
			cd $mediadir/
			BADONMEDIA=$(ls -al -R | grep -ic -f $srcdir/badpatterns.txt)
			if [ $BADONMEDIA -ne 0 ];
			then #Autorun exists, no U3 in autorun, suspicious exe in autorun, bad files on media
				printf "There are malicious files on the media. The following is a list of malicious files found\n" >> $outdir/results.txt
				cd $mediadir/
				ls -aR | grep -i -f $srcdir/badpatterns.txt >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/infected.html
				#exit 0
			else #Autorun exists, no U3 in autorun, suspicious exe in autorun, no bad files on media
				printf "There were no malicious files found on the media\n" >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/infected.html
				#exit 0
			fi
		
		else #Autorun exists, no U3 in autorun, no suspicious exe in autorun
			printf "There were no suspicious executable files referenced in autorun.inf\n" >> $outdir/results.txt
			rm $outdir/autorun.txt
			
			#Test for bad stuff on media
			cd $mediadir/
			BADONMEDIA=$(ls -al -R | grep -ic -f $srcdir/badpatterns.txt)
			if [ $BADONMEDIA -ne 0 ];
			then #Autorun exists, no U3 in autorun, no suspicious exe in autorun, bad files on media
				printf "There are malicious files on the media. The following is a list of malicious files found\n" >> $outdir/results.txt
				cd $mediadir/
				ls -aR | grep -i -f $srcdir/badpatterns.txt >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/infected.html
				#exit 0
			else #Autorun exists, no U3 in autorun, no suspicious exe in autorun, no bad files on media
				printf "There were no malicious files found on the media\n" >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/clean.html
				#exit 0
			fi

		fi

	else #Autorun exists, There is LaunchU3 mentioned in the autorun file
		printf "There is a line referencing 'U3' in autorun.inf\n" >> $outdir/results.txt
		
		#Check for bad patterns in autorun.inf
		KNOWNBADONAR=$(grep -ic -f $srcdir/badpatterns.txt $outdir/autorun.txt)
		if [ $KNOWNBADONAR -ne 0 ];
		then #Autorun exists, Launch U3 exists in autorun, suspect files found in autorun.inf
			printf "There are lines in 'autorun.inf' that reference bad files\n" >> $outdir/results.txt					
			rm $outdir/autorun.txt
		
			#Test for bad stuff on media
			cd $mediadir/
			BADONMEDIA=$(ls -al -R | grep -ic -f $srcdir/badpatterns.txt)
			if [ $BADONMEDIA -ne 0 ];
			then #Autorun exists, U3 exists in autorun, suspect files in autorun, bad files on media
				printf "There are malicious files on the media. The following is a list of malicious files found\n" >> $outdir/results.txt
				cd $mediadir/
				ls -aR | grep -i -f $srcdir/badpatterns.txt >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/infected.html
				#exit 0
			else #Autorun exists, U3 exists in autorun, suspect files in autorun, no bad files on media
				printf "There were no malicious files found on the media\n" >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/infected.html
				#exit 0
			fi

		else #Autorun exists, LaunchU3 exists in the autorun file, no suspect files found in autorun
			printf "autorun.inf does not reference any bad files\n" >> $outdir/results.txt
			rm $outdir/autorun.txt
			
			#Test for bad stuff on media
			cd $mediadir/
			BADONMEDIA=$(ls -al -R | grep -ic -f $srcdir/badpatterns.txt)
			if [ $BADONMEDIA -ne 0 ];
			then #Autorun exists, LaunchU3 exists in the autorun file, no suspect files found in autorun, bad files on media
				printf "There are malicious files on the media. The following is a list of malicious files found\n" >> $outdir/results.txt
				cd $mediadir/
				ls -aR | grep -i -f $srcdir/badpatterns.txt >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/infected.html
				#exit 0
			else #Autorun exists, LaunchU3 exists in the autorun file, no suspect files found in autorun, no bad files on media
				printf "There were no malicious files found on the media\n" >> $outdir/results.txt
				#cd $srcdir/
				#sh $srcdir/unmount.sh
				firefox $srcdir/clean.html
				#exit 0
			fi

		fi 

	fi

else #autorun.inf does not exist 
	printf "There is no 'autorun.inf' file on the media\n" >> $outdir/results.txt
		
	#Test for bad stuff on media
	cd $mediadir/
	BADONMEDIA=$(ls -al -R | grep -ic -f $srcdir/badpatterns.txt)
	if [ $BADONMEDIA -ne 0 ];
	then #autorun.inf does not exist, bad files on media
		printf "There are malicious files on the media. The following is a list of malicious files found\n" >> $outdir/results.txt
		cd $mediadir/
		ls -aR | grep -i -f $srcdir/badpatterns.txt >> $outdir/results.txt
		#cd $srcdir/
		#sh $srcdir/unmount.sh
		firefox $srcdir/infected.html
		#exit 0
	else #autorun.inf does not exist, no bad files on media
		printf "There were no malicious files found on the media\n" >> $outdir/results.txt
		#cd $srcdir/
		#sh $srcdir/unmount.sh
		firefox $srcdir/clean.html
		#exit 0
	fi

fi

exit 0
		
